join

package
v0.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 23, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package join demonstrates joining two workflow branches.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(ctx context.Context, database *sql.DB, input int) (_ int, err error)

Run executes the join example using a caller-owned database.

Types

This section is empty.

Directories

Path Synopsis
Command pg runs the joined workflow example with pgx's database/sql driver.
Command pg runs the joined workflow example with pgx's database/sql driver.
Command sqlite runs the joined workflow example with modernc SQLite.
Command sqlite runs the joined workflow example with modernc SQLite.

Jump to